3 ms·
https://github.com/py2many/py2many/pull/653 https://github.com/py2many/py2many/pull/653 Transpiling the python version in the blog to mojo gives me a 4x speedu
by adsharma 2y ago
https://github.com/py2many/py2many/pull/653 https://github.com/py2many/py2many/pull/653
Transpiling the python version in the blog to mojo gives me a 4x speedup.
Had to hand edit a couple of things:
- List to bytearray conversion is not working yet
- Can't iterate over SIMD. So a "for x in list" loop has to be rewritten as a range based loop.
With a bit more work, the manual edits won't be necessary.
- adsharma 2y agoGenerated code: https://gist.github.com/adsharma/22ec18664ce4a59750b78fddc5801045 https://gist.github.com/adsharma/22ec18664ce4a59750b78fddc58... Edited code: https://gist.github.com/adsharma/72516d8333a25fd8e350472568d944de https://gist.github.com/adsharma/72516d8333a25fd8e350472568d...
- fnands 2y agoOh! Cool project! You mean 4x speedup over Python?
- adsharma 2y agoYes. Details in the pull request linked above